#[repr(i32)]pub enum ResultShape {
Unspecified = 0,
Relation = 1,
Collection = 2,
Tuple = 3,
Scalar = 4,
}Expand description
Result shape, sent on the first chunk so clients can reassemble.
Variants
Implementations
Sourceimpl ResultShape
impl ResultShape
Sourceimpl ResultShape
impl ResultShape
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.