pub struct QueryResultChunk {
pub shape: i32,
pub rows: Vec<u8>,
pub last: bool,
}Fields
shape: i32rows: Vec<u8>Composite-encoded EDN. Relations/collections stream vectors of rows to concatenate; tuple/scalar results arrive in a single chunk.
last: boolImplementations
Sourceimpl QueryResultChunk
impl QueryResultChunk
Sourcepub fn shape(&self) -> ResultShape
pub fn shape(&self) -> ResultShape
Returns the enum value of shape, or the default if the field is set to an invalid enum value.
Sourcepub fn set_shape(&mut self, value: ResultShape)
pub fn set_shape(&mut self, value: ResultShape)
Sets shape to the provided enum value.