pub struct SetIndexPolicyResponse {
pub interval_ms: u64,
pub backoff: u32,
pub tail_threshold: u64,
pub tail_deadline_ms: u64,
}Expand description
The policy in effect after applying the request.
Fields
interval_ms: u64backoff: u32tail_threshold: u64tail_deadline_ms: u64Trait Implementations
Sourceimpl Clone for SetIndexPolicyResponse
impl Clone for SetIndexPolicyResponse
Sourcefn clone(&self) -> SetIndexPolicyResponse
fn clone(&self) -> SetIndexPolicyResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SetIndexPolicyResponse
Sourceimpl Debug for SetIndexPolicyResponse
impl Debug for SetIndexPolicyResponse
Sourceimpl Default for SetIndexPolicyResponse
impl Default for SetIndexPolicyResponse
impl Eq for SetIndexPolicyResponse
Sourceimpl Hash for SetIndexPolicyResponse
impl Hash for SetIndexPolicyResponse
Sourceimpl Message for SetIndexPolicyResponse
impl Message for SetIndexPolicyResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetIndexPolicyResponse
impl PartialEq for SetIndexPolicyResponse
impl StructuralPartialEq for SetIndexPolicyResponse