pub struct StatusResponse {Show 15 fields
pub basis_t: u64,
pub index_basis_t: u64,
pub lease_owner: String,
pub lease_version: u64,
pub lease_expires_unix_ms: i64,
pub datom_count: u64,
pub entity_count: u64,
pub attribute_count: u64,
pub transaction_count: u64,
pub transaction_failure_count: u64,
pub transaction_queue_depth: u64,
pub index_lag: u64,
pub indexing_runs: u64,
pub gc_runs: u64,
pub gc_swept_blobs: u64,
}Fields
basis_t: u64index_basis_t: u64lease_owner: Stringlease_version: u64lease_expires_unix_ms: i64datom_count: u64entity_count: u64attribute_count: u64transaction_count: u64transaction_failure_count: u64transaction_queue_depth: u64index_lag: u64indexing_runs: u64gc_runs: u64gc_swept_blobs: u64Trait Implementations
Sourceimpl Clone for StatusResponse
impl Clone for StatusResponse
Sourcefn clone(&self) -> StatusResponse
fn clone(&self) -> StatusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatusResponse
impl Debug for StatusResponse
Sourceimpl Default for StatusResponse
impl Default for StatusResponse
impl Eq for StatusResponse
Sourceimpl Hash for StatusResponse
impl Hash for StatusResponse
Sourceimpl Message for StatusResponse
impl Message for StatusResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StatusResponse
impl PartialEq for StatusResponse
impl StructuralPartialEq for StatusResponse