Module schemaform

Module schemaform 

Boundary conversion from Datomic-style EDN attribute maps to the engine schema model, used by CreateDatabase.

Enums

SchemaFormError
Schema form conversion failure.

Constants

FIRST_ATTR_ID
Sequence of the first installable attribute entity in the db partition.

Functions

schema_from_edn
Parses Datomic-style attribute maps into a schema and ident registry.